@@ -170,8 +170,9 @@ ukb_df_field <- function(fileset, path = ".", data.pos = 2, as.lookup = FALSE) {
   name <- tolower(data[, "Description"]) %>%
     gsub(" - ", "_", x = .) %>%
     gsub(" ", "_", x = .) %>%
-    gsub("uses_data-coding.*simple_list.$", "", x = .) %>%
-    gsub("uses_data-coding.*hierarchical_tree.", "", x = .) %>%
+    gsub("uses.*data.*coding.*simple_list.$", "", x = .) %>%
+    gsub("uses.*data.*coding.*hierarchical_tree.", "", x = .) %>%
+    gsub("uses.*data.*coding_[0-9]*", "", x = .) %>%
     gsub("[^[:alnum:][:space:]_]", "", x = .) %>%
     gsub("__*", "_", x = .)
 
